summaryrefslogtreecommitdiff
path: root/gtk2_ardour/route_ui.cc
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/route_ui.cc')
-rw-r--r--gtk2_ardour/route_ui.cc6
1 files changed, 3 insertions, 3 deletions
diff --git a/gtk2_ardour/route_ui.cc b/gtk2_ardour/route_ui.cc
index cfb647a9a2..3ea8345570 100644
--- a/gtk2_ardour/route_ui.cc
+++ b/gtk2_ardour/route_ui.cc
@@ -37,7 +37,7 @@
#include <ardour/diskstream.h>
#include "i18n.h"
/* there is a compose() here.. */
//using namespace sigc;
using namespace Gtk;
using namespace Gtkmm2ext;
@@ -649,9 +649,9 @@ RouteUI::remove_this_route ()
string prompt;
if (is_audio_track()) {
- prompt = compose (_("Do you really want to remove track \"%1\" ?\nYou may also lose the playlist used by this track.\n(cannot be undone)"), _route.name());
+ prompt = string_compose (_("Do you really want to remove track \"%1\" ?\nYou may also lose the playlist used by this track.\n(cannot be undone)"), _route.name());
} else {
- prompt = compose (_("Do you really want to remove bus \"%1\" ?\n(cannot be undone)"), _route.name());
+ prompt = string_compose (_("Do you really want to remove bus \"%1\" ?\n(cannot be undone)"), _route.name());
}
choices.push_back (_("Yes, remove it."));
@@ -37,7 +37,7 @@
#include <ardour/diskstream.h>
#include "i18n.h"
-/* there is a compose() here.. */
+/* there is a string_compose() here.. */
//using namespace sigc;
using namespace Gtk;